@@ -101,11 +101,6 @@ class TestCase(HttpRequest):
             method = ResponseResult.method
             path: str = ResponseResult.path
             allure.dynamic.title(f'[{method}]{path}')  # 设置用例标题
-            if 'qzd' in path:
-                project = path.split('/')[1]
-                allure.dynamic.feature(project)  # 设置用例feature
-            # self.assertStatusCode(200)
-            # self.assertPath('code', 0)
 
     @staticmethod
     def set_title(text):
@@ -121,7 +116,6 @@ class TestCase(HttpRequest):
         :param kwargs: 元素定位方式
         :return: 根据平台返回对应的元素
         """
-        element: typing.Union[AndroidElement, IosElement, WebElement] = None
         if self.platform == 'android':
             element = AndroidElement(**kwargs)
         elif self.platform == 'ios':
@@ -133,6 +127,12 @@ class TestCase(HttpRequest):
             sys.exit()
         return element
 
+    def click(self, **kwargs):
+        self.el(**kwargs).click()
+
+    def assertExist(self, **kwargs):
+        assert self.el(**kwargs).exists(timeout=3)
+
     def open(self, url, cookies: list = None):
         """
         访问链接为url的页码
@@ -198,6 +198,78 @@ class TestCase(HttpRequest):
         else:
             assert search_value == value, f'{search_value} != {value}'
 
+    def assertLocalPath(self, path, value, json_obj):
+        """
+        同assertPath，只是源数据不是请求响应，而是传入的json_ojb
+        @param path:
+        @param value:
+        @param json_obj:
+        @return:
+        """
+        search_value = jmespath.search(path, json_obj)
+        if search_value is None:
+            assert path is None, "{} No match".format(path)
+        else:
+            assert search_value == value, f'{search_value} != {value}'
+
+    def assertLenEq(self, path, value):
+        """
+        断言列表长度等于多少
+        doc: https://jmespath.org/
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        if isinstance(search_value, list):
+            assert len(search_value) == value, f"{search_value} 的长度不等于 {value}"
+        else:
+            raise Exception(f"{search_value} 不是列表")
+
+    def assertLenGt(self, path, value):
+        """
+        断言列表长度大于多少
+        doc: https://jmespath.org/
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        if isinstance(search_value, list):
+            assert len(search_value) > value, f"{search_value} 的长度不大于 {value}"
+        else:
+            raise Exception(f"{search_value} 不是列表")
+
+    def assertIn(self, path, value_list: list):
+        """
+        断言匹配结果被value_list包含
+        @param path:
+        @param value_list:
+        @return:
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        assert search_value in value_list, f"{value_list} 不包含 {search_value}"
+
+    def assertContains(self, path, value):
+        """
+        断言匹配结果包含value
+        @param path:
+        @param value:
+        @return:
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        assert value in search_value, f"{search_value} 不包含 {value}"
+
+    def assertType(self, path, value_type):
+        if not isinstance(value_type, type):
+            if value_type == 'int':
+                value_type = int
+            elif value_type == 'str':
+                value_type = str
+            elif value_type == 'list':
+                value_type = list
+            elif value_type == 'dict':
+                value_type = dict
+            else:
+                value_type = str
+
+        search_value = jmespath.search(path, ResponseResult.response)
+        assert isinstance(search_value, value_type), f'{search_value} 不是 {value_type} 类型'
+
     def assertCode(self, code):
         """
         断言返回json中的code
