@@ -93,7 +93,7 @@ class TestMain(object):
 
         # 用例完成后操作
         conf.set_name('api', 'headers', json.dumps({}))  # 清除登录态
-        os.system('allure generate allure-results -o allure-report --clean')  # 生成报告
+        os.system('allure generate allure-results -o report --clean')  # 生成报告
 
 
 main = TestMain
